| Title: | Composite Spectra Analysis (CSA) for High-Resolution Mass Spectrometry Analyses |
|---|---|
| Description: | A fragmentation spectra detection pipeline for high-throughput LC/HRMS data processing using peaklists generated by the 'IDSL.IPA' workflow <doi:10.1021/acs.jproteome.2c00120>. The 'IDSL.CSA' package can deconvolute fragmentation spectra from Composite Spectra Analysis (CSA), Data Dependent Acquisition (DDA) analysis, and various Data-Independent Acquisition (DIA) methods such as MS^E, All-Ion Fragmentation (AIF) and SWATH-MS analysis. The 'IDSL.CSA' package was introduced in <doi:10.1021/acs.analchem.3c00376>. |
| Authors: | Sadjad Fakouri-Baygi [aut]
|
| Maintainer: | Dinesh Barupal <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.2 |
| Built: | 2026-05-20 05:46:52 UTC |
| Source: | https://github.com/idslme/idsl.csa |
This function detects frequent matched compounds across multiple samples on the aligned peak table matrix.
aligned_fragmentation_spectra_annotator(PARAM_AT, output_path)aligned_fragmentation_spectra_annotator(PARAM_AT, output_path)
PARAM_AT |
a parameter driven from the 'CSA_AlignedTable_xlsxAnalyzer' module. |
output_path |
output path |
This function stores '.Rdata' and '.csv' data from dataframe of aligned fragmentation spectra.
This function updates IDSL.IPA peaklists with IDSL.CSA grouping
CSA_adductAnnotator(IPApeakList, CSA_peaklist, massError)CSA_adductAnnotator(IPApeakList, CSA_peaklist, massError)
IPApeakList |
IDSL.IPA peaklist |
CSA_peaklist |
A dataframe peaklist of co-detected CSA analysis. |
massError |
Mass accuracy in Da |
IDSL.IPA peaklists with IDSL.CSA grouping
This function generates integrated and most abundant aligned spectra from the aligned spectra
CSA_alignedMetaSpectraCataloger(address_input_msp, peakXcol, peak_height, CSA_aligned_property_table, groupedID, minTanimotoCoefficient = 0.5, number_processing_threads = 1)CSA_alignedMetaSpectraCataloger(address_input_msp, peakXcol, peak_height, CSA_aligned_property_table, groupedID, minTanimotoCoefficient = 0.5, number_processing_threads = 1)
address_input_msp |
address of the .msp files generated via IDSL.IPA DIA grouping |
peakXcol |
aligned indexed peak table |
peak_height |
aligned peak height table |
CSA_aligned_property_table |
a matrix of three columns of "IPA detection frequency", "median_height", and "median_R13C" for the aligned peak table |
groupedID |
A 2-column dataframe of 'Co-detectedIDs' and 'TanimotoCoefficients' from the 'CSA_alignedPeaksTanimotoCoefficientCalculator' module |
minTanimotoCoefficient |
minimum Tanimoto coefficient |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A list of two objects for 'MSP_integrated_aligned_spectra' and 'MSP_most_abundant_aligned_spectra'
This function groups co-detected peaks on the aligned table.
CSA_alignedPeaksTanimotoCoefficientCalculator(address_input_msp, peakXcol, minPercenetageDetection = 5, minNumberFragments = 2, minTanimotoCoefficient = 0.1, RTtolerance = 0.05, number_processing_threads = 1)CSA_alignedPeaksTanimotoCoefficientCalculator(address_input_msp, peakXcol, minPercenetageDetection = 5, minNumberFragments = 2, minTanimotoCoefficient = 0.1, RTtolerance = 0.05, number_processing_threads = 1)
address_input_msp |
address of the .msp files generated via IDSL.IPA CSA aggregation |
peakXcol |
aligned indexed peak table |
minPercenetageDetection |
minimum CSA frequency detection |
minNumberFragments |
minimum frequency |
minTanimotoCoefficient |
minimum Tanimoto coefficient |
RTtolerance |
retention time tolerance to detect common peaks |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A 2-column dataframe of 'Co-detectedIDs' and 'TanimotoCoefficients'
This function processes the spreadsheet of the 'AlignedTable' tab to ensure the parameter inputs are consistent with the requirements of the IDSL.CSA pipeline.
CSA_AlignedTable_xlsxAnalyzer(spreadsheet)CSA_AlignedTable_xlsxAnalyzer(spreadsheet)
spreadsheet |
'AlignedTable' tab of the parameter spreadsheet |
This function returns the aligned table parameters to feed the 'aligned_fragmentation_spectra_annotator' function.
This function detects fragmentation peaks for the Composite Spectra Analysis (CSA) using IDSL.IPA peaklists.
CSA_fragmentationPeakDetection(CSA_hrms_address, CSA_hrms_file, tempAlignedTableSubsetsFolder = NULL, peaklist, selectedIPApeaks = NULL, RTtolerance, massError, minSNRbaseline, smoothingWindowMS1, scanTolerance, nSpline, topRatioPeakHeight, minIonRangeDifference, minNumCSApeaks, pearsonRHOthreshold, outputCSAeic = NULL)CSA_fragmentationPeakDetection(CSA_hrms_address, CSA_hrms_file, tempAlignedTableSubsetsFolder = NULL, peaklist, selectedIPApeaks = NULL, RTtolerance, massError, minSNRbaseline, smoothingWindowMS1, scanTolerance, nSpline, topRatioPeakHeight, minIonRangeDifference, minNumCSApeaks, pearsonRHOthreshold, outputCSAeic = NULL)
CSA_hrms_address |
path to the HRMS file |
CSA_hrms_file |
CSA HRMS file |
tempAlignedTableSubsetsFolder |
tempAlignedTableSubsetsFolder |
peaklist |
IDSL.IPA peaklist |
selectedIPApeaks |
A vector of selected IDSL.IPA peaks only when a number of IDSL.IPA peaks from one peaklist is processed. When 'NULL' is selected, the entire peaks in the peaklist are processed. |
RTtolerance |
retention time tolerance to detect common peaks |
massError |
Mass accuracy in Da |
minSNRbaseline |
A minimum baseline S/N threshold for IDSL.IPA pseudo-precursor m/z |
smoothingWindowMS1 |
number of scans for peak smoothing. |
scanTolerance |
a scan tolerance to extend the chromatogram for better calculations. |
nSpline |
number of points for further smoothing using a cubic spline smoothing method to add more points to calculate Pearson correlation rho values |
topRatioPeakHeight |
The top percentage of the chromatographic peak to calculate Pearson correlation rho values |
minIonRangeDifference |
Minimum distance (Da) between lowest and highest m/z to prevent clustering isotopic envelopes |
minNumCSApeaks |
Minumum number of ions in a CSA cluster |
pearsonRHOthreshold |
Minimum threshold for Pearson correlation rho values |
outputCSAeic |
When 'NULL' CSA EICs are not plotted. 'outputCSAeic' represents an address to save CSA EICs figures. |
A dataframe peaklist of co-detected CSA analysis.
[1] Fakouri Baygi, S., Kumar, Y., Barupal, D.K. (2022). IDSL.IPA Characterizes the Organic Chemical Space in Untargeted LC/HRMS Data Sets. Journal of Proteome Research, 21(6), 1485-1494, doi:10.1021/acs.jproteome.2c00120
[2] Fakouri Baygi, S., Fernando, S., Hopke, P.K., Holsen, T.M., Crimmins, B.S. (2021). Nontargeted discovery of novel contaminants in the Great Lakes region: A comparison of fish fillets and fish consumers. Environmental Science & Technology, 55(6), 3765-3774, doi:10.1021/acs.est.0c08507
default values for PARAM SPEC
data("CSA_PARAM_SPEC")data("CSA_PARAM_SPEC")
A data frame on the following 2 variables.
Parameter IDa character vector
User provided inputa numerical vector
data(CSA_PARAM_SPEC)data(CSA_PARAM_SPEC)
CSA reference xlsxAnalyzer
CSA_reference_xlsxAnalyzer(ref_xlsx_file, input_path_hrms = NULL, PARAM = NULL, PARAM_ID = "", checkpoint_parameter = TRUE)CSA_reference_xlsxAnalyzer(ref_xlsx_file, input_path_hrms = NULL, PARAM = NULL, PARAM_ID = "", checkpoint_parameter = TRUE)
ref_xlsx_file |
ref_xlsx_file |
input_path_hrms |
input_path_hrms |
PARAM |
PARAM |
PARAM_ID |
PARAM_ID |
checkpoint_parameter |
checkpoint_parameter |
ref_table |
ref_table |
PARAM |
PARAM |
checkpoint_parameter |
checkpoint_parameter |
This function executes the CSA workflow.
CSA_workflow(PARAM_CSA)CSA_workflow(PARAM_CSA)
PARAM_CSA |
PARAM_CSA |
This module generates '.msp' files from DDA analysis.
s_path <- system.file("extdata", package = "IDSL.CSA") SSh1 <- paste0(s_path,"/CSA_parameters.xlsx") ## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_csa_test_files.zip") spreadsheet <- readxl::read_xlsx(SSh1, sheet = "CSA") PARAM_CSA <- cbind(spreadsheet[, 2], spreadsheet[, 4]) download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_csa_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) PARAM_CSA[2, 2] <- "NO" PARAM_CSA[3, 2] <- "NO" PARAM_CSA[5, 2] <- temp_wd PARAM_CSA[8, 2] <- temp_wd PARAM_CSA[9, 2] <- "NA" PARAM_CSA[11, 2] <- temp_wd ## To ensure `PARAM_CSA` is consistent with the `CSA_workflow` PARAM_CSA <- CSA_xlsxAnalyzer(PARAM_CSA) ## CSA_workflow(PARAM_CSA)s_path <- system.file("extdata", package = "IDSL.CSA") SSh1 <- paste0(s_path,"/CSA_parameters.xlsx") ## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_csa_test_files.zip") spreadsheet <- readxl::read_xlsx(SSh1, sheet = "CSA") PARAM_CSA <- cbind(spreadsheet[, 2], spreadsheet[, 4]) download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_csa_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) PARAM_CSA[2, 2] <- "NO" PARAM_CSA[3, 2] <- "NO" PARAM_CSA[5, 2] <- temp_wd PARAM_CSA[8, 2] <- temp_wd PARAM_CSA[9, 2] <- "NA" PARAM_CSA[11, 2] <- temp_wd ## To ensure `PARAM_CSA` is consistent with the `CSA_workflow` PARAM_CSA <- CSA_xlsxAnalyzer(PARAM_CSA) ## CSA_workflow(PARAM_CSA)
This function processes the spreadsheet of the CSA parameters to ensure the parameter inputs are consistent with the requirements of the IDSL.CSA pipeline.
CSA_xlsxAnalyzer(spreadsheet)CSA_xlsxAnalyzer(spreadsheet)
spreadsheet |
CSA tab of the parameter spreadsheet |
This function returns the CSA parameters to feed the 'CSA_workflow' function.
This function detects fragmentation peaks for the Data-Dependent Acquisition (DDA) analysis.
DDA_fragmentationPeakDetection(DDA_hrms_address, DDA_hrms_file, peaklist, selectedIPApeaks, massErrorPrecursor, DDAprocessingMode = 'MostIntenseDDAspectra', outputDDAspectra = NULL, number_processing_threads = 1)DDA_fragmentationPeakDetection(DDA_hrms_address, DDA_hrms_file, peaklist, selectedIPApeaks, massErrorPrecursor, DDAprocessingMode = 'MostIntenseDDAspectra', outputDDAspectra = NULL, number_processing_threads = 1)
DDA_hrms_address |
path to the HRMS file |
DDA_hrms_file |
DDA HRMS file |
peaklist |
IDSL.IPA peaklist |
selectedIPApeaks |
A vector of selected IDSL.IPA peaks only when a number of IDSL.IPA peaks from one peaklist is processed. |
massErrorPrecursor |
Mass accuracy (Da) to find precursor m/z in IDSL.IPA peaklists |
DDAprocessingMode |
c('MostIntenseDDAspectra', c('DDAspectraIntegration', massErrorIntegration), c('IonFiltering', massErrorIonFiltering, minPercentageDetectedScans, rsdCutoff, pearsonRHOthreshold)). Required variables for each DDA processing mode should be provided in this vector. |
outputDDAspectra |
When 'NULL' DDA spectra are not plotted. 'outputDDAspectra' represents an address to save DDA spectra figures. |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A dataframe peaklist of co-detected DDA analysis.
This function stacks all DDA scans.
DDA_rawSpectraDeconvolution(DDA_hrms_address, DDA_hrms_file, rawDDAspectraVar = NULL, number_processing_threads = 1)DDA_rawSpectraDeconvolution(DDA_hrms_address, DDA_hrms_file, rawDDAspectraVar = NULL, number_processing_threads = 1)
DDA_hrms_address |
path to the HRMS file |
DDA_hrms_file |
DDA HRMS file |
rawDDAspectraVar |
c(NULL, list(precursorMZvec, precursorRTvec, massError, RTtolerance)). When NULL, all scans with precursor values are used for DDA peaklist generation. When the list is provided, it filters the scans with respect to predefined 'precursorMZvec' and 'precursorRTvec' values. |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A dataframe stacked DDA scans.
This function runs the Data-Dependent Acquisition (DDA) analysis.
DDA_workflow(PARAM_DDA)DDA_workflow(PARAM_DDA)
PARAM_DDA |
DDA parameters |
This module generates '.msp' files from DDA analysis.
s_path <- system.file("extdata", package = "IDSL.CSA") SSh1 <- paste0(s_path,"/CSA_parameters.xlsx") ## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_dda_test_files.zip") spreadsheet <- readxl::read_xlsx(SSh1, sheet = "DDA") PARAM_DDA <- cbind(spreadsheet[, 2], spreadsheet[, 4]) download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_dda_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) PARAM_DDA[2, 2] <- "no" PARAM_DDA[4, 2] <- temp_wd PARAM_DDA[7, 2] <- temp_wd PARAM_DDA[8, 2] <- "NA" PARAM_DDA[11, 2] <- temp_wd ## To ensure `PARAM_DDA` is consistent with the `DDA_workflow` PARAM_DDA <- DDA_xlsxAnalyzer(PARAM_DDA) ## DDA_workflow(PARAM_DDA)s_path <- system.file("extdata", package = "IDSL.CSA") SSh1 <- paste0(s_path,"/CSA_parameters.xlsx") ## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_dda_test_files.zip") spreadsheet <- readxl::read_xlsx(SSh1, sheet = "DDA") PARAM_DDA <- cbind(spreadsheet[, 2], spreadsheet[, 4]) download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_dda_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) PARAM_DDA[2, 2] <- "no" PARAM_DDA[4, 2] <- temp_wd PARAM_DDA[7, 2] <- temp_wd PARAM_DDA[8, 2] <- "NA" PARAM_DDA[11, 2] <- temp_wd ## To ensure `PARAM_DDA` is consistent with the `DDA_workflow` PARAM_DDA <- DDA_xlsxAnalyzer(PARAM_DDA) ## DDA_workflow(PARAM_DDA)
This function processes the spreadsheet of the DDA spreadsheet tab to ensure the parameter inputs are in agreement with requirements of the Data-Dependent Acquisition (DDA) analysis.
DDA_xlsxAnalyzer(spreadsheet)DDA_xlsxAnalyzer(spreadsheet)
spreadsheet |
DDA spreadsheet tab |
DDA parameters to feed the 'DDA_workflow' function.
DDA to msp
DDA2msp(input_path_hrms, file_name_hrms = NULL, number_processing_threads = 1)DDA2msp(input_path_hrms, file_name_hrms = NULL, number_processing_threads = 1)
input_path_hrms |
path to the HRMS file |
file_name_hrms |
file_name_hrms |
number_processing_threads |
Number of processing threads for multi-threaded processing |
This module generates '.msp' files from DDA analysis.
## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_rawdda_test_files.zip") download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_rawdda_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) DDA2msp(input_path_hrms = temp_wd, file_name_hrms = NULL, number_processing_threads = 1)## To see the results, use a known folder instead of the `tempdir()` command temp_wd <- tempdir() temp_wd_zip <- paste0(temp_wd, "/idsl_rawdda_test_files.zip") download.file(paste0("https://github.com/idslme/IDSL.CSA/blob/main/", "CSA_educational_files/idsl_rawdda_test_files.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) DDA2msp(input_path_hrms = temp_wd, file_name_hrms = NULL, number_processing_threads = 1)
This function detects fragmentation peaks for the Data-Independent Acquisition (DIA) analysis at ms level 1.
DIA_MS1_fragmentationPeakDetection(DIA_hrms_address, DIA_hrms_file, peaklist, selectedIPApeaks, massError, smoothingWindowMS1, scanTolerance, nSpline, topRatioPeakHeight, intensityThresholdFragment, pearsonRHOthreshold, outputDIAeic = NULL, number_processing_threads = 1)DIA_MS1_fragmentationPeakDetection(DIA_hrms_address, DIA_hrms_file, peaklist, selectedIPApeaks, massError, smoothingWindowMS1, scanTolerance, nSpline, topRatioPeakHeight, intensityThresholdFragment, pearsonRHOthreshold, outputDIAeic = NULL, number_processing_threads = 1)
DIA_hrms_address |
path to the HRMS file |
DIA_hrms_file |
DIA HRMS file |
peaklist |
IDSL.IPA peaklist |
selectedIPApeaks |
A vector of selected IDSL.IPA peaks only when a number of IDSL.IPA peaks from one peaklist is processed. |
massError |
Mass accuracy in Da |
smoothingWindowMS1 |
number of scans for peak smoothing. |
scanTolerance |
a scan tolerance to extend the chromatogram for better calculations. |
nSpline |
number of points for further smoothing using a cubic spline smoothing method to add more points to calculate Pearson correlation rho values |
topRatioPeakHeight |
The top percentage of the chromatographic peak to calculate Pearson correlation rho values |
intensityThresholdFragment |
a value to represent intensity threshold for the fragment at the apex chromatogram scan |
pearsonRHOthreshold |
Minimum threshold for Pearson correlation rho values |
outputDIAeic |
When 'NULL' DIA EICs are not plotted. 'outputDIAeic' represents an address to save DIA EICs figures. |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A dataframe peaklist of co-detected DIA analysis.
Fakouri Baygi, S., Fernando, S., Hopke, P.K., Holsen, T.M., Crimmins, B.S. (2021). Nontargeted discovery of novel contaminants in the Great Lakes region: A comparison of fish fillets and fish consumers. Environmental Science & Technology, 55(6), 3765-3774, doi:10.1021/acs.est.0c08507
This function detects fragmentation peaks for the DIA analysis at MS level 2.
DIA_MS2_fragmentationPeakDetection(DIA_hrms_address, DIA_hrms_file, peaklist, selectedIPApeaks, massError, smoothingWindowMS1, smoothingWindowMS2, scanTolerance, nSpline, topRatioPeakHeight, intensityThresholdFragment, pearsonRHOthreshold, outputDIAeic = NULL, number_processing_threads = 1)DIA_MS2_fragmentationPeakDetection(DIA_hrms_address, DIA_hrms_file, peaklist, selectedIPApeaks, massError, smoothingWindowMS1, smoothingWindowMS2, scanTolerance, nSpline, topRatioPeakHeight, intensityThresholdFragment, pearsonRHOthreshold, outputDIAeic = NULL, number_processing_threads = 1)
DIA_hrms_address |
path to the HRMS file |
DIA_hrms_file |
DIA HRMS file |
peaklist |
IDSL.IPA peaklist |
selectedIPApeaks |
A vector of selected IDSL.IPA peaks only when a number of IDSL.IPA peaks from one peaklist is processed. |
massError |
Mass accuracy in Da |
smoothingWindowMS1 |
Number of scans for peak smoothing in MS1 channel |
smoothingWindowMS2 |
Number of scans for peak smoothing in MS2 channel |
scanTolerance |
a scan tolerance to extend the chromatogram for better calculations. |
nSpline |
number of points for further smoothing using a cubic spline smoothing method to add more points to calculate Pearson correlation rho values |
topRatioPeakHeight |
The top percentage of the chromatographic peak to calculate Pearson correlation rho values |
intensityThresholdFragment |
a value to represent intensity threshold for the fragment at the apex chromatogram scan in MS2 channel |
pearsonRHOthreshold |
Minimum threshold for Pearson correlation rho values |
outputDIAeic |
When 'NULL' DIA EICs are not plotted. 'outputDIAeic' represents an address to save DIA EICs figures. |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A dataframe peaklist of co-detected DIA analysis.
Fakouri Baygi, S., Fernando, S., Hopke, P.K., Holsen, T.M., Crimmins, B.S. (2021). Nontargeted discovery of novel contaminants in the Great Lakes region: A comparison of fish fillets and fish consumers. Environmental Science & Technology, 55(6), 3765-3774, doi:10.1021/acs.est.0c08507
This function runs the Data-Independent Acquisition (DIA) analysis.
DIA_workflow(PARAM_DIA)DIA_workflow(PARAM_DIA)
PARAM_DIA |
DIA parameters |
This module generates '.msp' files from DDA analysis.
This function processes the spreadsheet of the DIA spreadsheet tab to ensure the parameter inputs are in agreement with requirements of the Data-Independent Acquisition (DIA) analysis.
DIA_xlsxAnalyzer(spreadsheet)DIA_xlsxAnalyzer(spreadsheet)
spreadsheet |
DIA spreadsheet tab |
DIA parameters to feed the 'DIA_workflow' function.
This function creates standard .msp files that can also be used for Pepsearch.
IDSL.CSA_MSPgenerator(CSA_peaklist, msLevel, spectral_search_mode = "dda", spectral_search_mode_option = NA, number_processing_threads = 1)IDSL.CSA_MSPgenerator(CSA_peaklist, msLevel, spectral_search_mode = "dda", spectral_search_mode_option = NA, number_processing_threads = 1)
CSA_peaklist |
A dataframe peaklist of co-detected peaks |
spectral_search_mode |
Type of analysis. spectral_search_mode = c("dda", "dia", "csa") |
msLevel |
MS level = c(1, 2) |
spectral_search_mode_option |
Secondary type of analysis. spectral_search_mode_option = c(NA, "rawddaspectra", "alignedtable") |
number_processing_threads |
Number of processing threads for multi-threaded processing |
A string of standard .msp file
This function creates reference standard .msp files.
IDSL.CSA_referenceMSPgenerator(REF_peaklist, refTable, selectedIPApeaks_IDref, msLevel, spectral_search_mode = "dda", spectral_search_mode_option = NA)IDSL.CSA_referenceMSPgenerator(REF_peaklist, refTable, selectedIPApeaks_IDref, msLevel, spectral_search_mode = "dda", spectral_search_mode_option = NA)
REF_peaklist |
A dataframe peaklist of co-detected peaks |
refTable |
reference CSA table |
selectedIPApeaks_IDref |
selectedIPApeaks_IDref |
msLevel |
MS level = c(1, 2) |
spectral_search_mode |
Type of analysis. spectral_search_mode = c("dda", "dia", "csa") |
spectral_search_mode_option |
Secondary type of analysis. spectral_search_mode_option = c(NA, "rawddaspectra", "alignedtable") |
A string of standard .msp file
This function executes the CSA workflow.
IDSL.CSA_workflow(spreadsheet)IDSL.CSA_workflow(spreadsheet)
spreadsheet |
CSA spreadsheet |
This function organizes the IDSL.CSA file processing for better performance using the template spreadsheet.
This function processes the spreadsheet of the CSA parameters to ensure the parameter inputs are consistent with the requirements of the IDSL.CSA pipeline.
IDSL.CSA_xlsxAnalyzer(spreadsheet)IDSL.CSA_xlsxAnalyzer(spreadsheet)
spreadsheet |
'Start' tab of the parameter spreadsheet |
This function returns the CSA parameters to feed the 'IDSL.CSA_workflow' function.
This data consists of adducts and mass differences for common ionization pathways in negative modes.
data("negativeAdducts")data("negativeAdducts")
A data frame on the following 2 variables.
Adducta character vector
massAdducta numerical vector
data(negativeAdducts)data(negativeAdducts)
This data consists of adducts and mass differences for common ionization pathways in positive modes.
data("positiveAdducts")data("positiveAdducts")
A data frame on the following 2 variables.
Adducta character vector
massAdducta numerical vector
data(positiveAdducts)data(positiveAdducts)